@@ -378,7 +378,7 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
         warning("Time series of thermal availability have not been stored in output. Time series stored in input will be used, but the result may be wrong if they have changed since the simulation has been run.")
       }
     } else {
-      if (!.getSuccess(file.path(opts$simPath, "ts-generator/thermal/mc-0"), opts$token, opts$timeout)) {
+      if (!.getSuccess(file.path(opts$simPath, "ts-generator/thermal/mc-0"), token = opts$token, timeout = opts$timeout, config = opts$httr_config)) {
         warning("Time series of thermal availability have not been stored in output. Time series stored in input will be used, but the result may be wrong if they have changed since the simulation has been run.")
       }
     }
@@ -393,7 +393,7 @@ readAntares <- function(areas = NULL, links = NULL, clusters = NULL,
         warning("Time series of hydro storage have not been stored in output. Time series stored in input will be used, but the result may be wrong if they have changed since the simulation has been run.")
       }
     } else {
-      if (!.getSuccess(file.path(opts$simPath, "ts-generator/hydro/mc-0"), opts$token, opts$timeout)) {
+      if (!.getSuccess(file.path(opts$simPath, "ts-generator/hydro/mc-0"), token = opts$token, timeout = opts$timeout, config = opts$httr_config)) {
         warning("Time series of hydro storage have not been stored in output. Time series stored in input will be used, but the result may be wrong if they have changed since the simulation has been run.")
       }
     }
